4.46. umbra.ui.themes — Umbra 1.0.9 documentation

# 4.46. umbra.ui.themes

highlighters.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the Application themes classes.

Others:

## 4.46.1. Module Attributes

`umbra.ui.themes.` `LOGGER`

`umbra.ui.themes.` `DEFAULT_FORMAT`

`umbra.ui.themes.` `DEFAULT_THEME`

`umbra.ui.themes.` `LOGGING_THEME`

## 4.46.2. Functions

`umbra.ui.themes.` `getFormat`(**kwargs)

  Returns a QTextCharFormat format.

  Parameters: | **kwargs (dict) – Format settings.
  Returns: | Format.
  Return type: | QTextCharFormat